using System;
using System.IO;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Azure.WebJobs;
using Microsoft.Azure.WebJobs.Extensions.Http;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Microsoft.Azure.Storage.Blob;

namespace LocalFunctionProj
{
    public static class HttpToBlob
    {
        [FunctionName("HttpToBlob")]
        public static async Task<IActionResult> Run(
            [HttpTrigger(AuthorizationLevel.Anonymous, "get", "post", Route = null)] HttpRequest req,
            [Blob("ivblob", Connection = "AzureWebJobsStorage")] CloudBlobContainer outputContainer,
            ILogger log)
        {
            log.LogInformation("C# HTTP trigger function processed a request.");

            await outputContainer.CreateIfNotExistsAsync();
            
            string name = req.Query["msg"];

            string requestBody = await new StreamReader(req.Body).ReadToEndAsync();
            dynamic data = JsonConvert.DeserializeObject(requestBody);
            name = name ?? data?.name;


            // var requestBody = await new StreamReader(httpRequest.Body).ReadToEndAsync();
            var blobName = Guid.NewGuid().ToString();
            var cloudBlockBlob = outputContainer.GetBlockBlobReference(blobName);
            
            if (!string.IsNullOrEmpty(name))
            {
                // Add a message to the output collection.
                await cloudBlockBlob.UploadTextAsync(requestBody);
            }
            return name != null
                ? (ActionResult)new OkObjectResult($"msg received = {name}")
                : new BadRequestObjectResult("Please pass a message on the query string or in the request body");
        }
    }
}